/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { DatasourceKey } from '@superset-ui/core';

describe('DatasourceKey', () => {
  it('should handle table data sources', () => {
    const datasourceKey = new DatasourceKey('5__table');
    expect(datasourceKey.toString()).toBe('5__table');
    expect(datasourceKey.toObject()).toEqual({ id: 5, type: 'table' });
  });

  it('should handle query data sources', () => {
    const datasourceKey = new DatasourceKey('5__query');
    expect(datasourceKey.toString()).toBe('5__query');
    expect(datasourceKey.toObject()).toEqual({ id: 5, type: 'query' });
  });
});
